==> iohub-sdk-client-1.0-20250421.031926-65-sources.jar: com/ovopark/iohub/sdk/client/Client2ControlRestClient.java <==
package com.ovopark.iohub.sdk.client;

import com.ovopark.iohub.sdk.model.*;
import com.ovopark.kernel.shared.Config;
import com.ovopark.kernel.shared.JSONAccessor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.FileSystemResource;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.ResponseEntity;
import org.springframework.http.client.SimpleClientHttpRequestFactory;
import org.springframework.http.converter.StringHttpMessageConverter;
import org.springframework.stereotype.Component;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import java.nio.charset.StandardCharsets;
import java.util.Map;

@JobClientActive
@Slf4j
@Component
public class Client2ControlRestClient implements Client2ControlTransport {


    final boolean verbose= Config.ConfigPriority.option().getBoolean("iohub.client.io.verbose",true);

    private final RestTemplate restTemplate;

    public Client2ControlRestClient() {
        SimpleClientHttpRequestFactory factory = new SimpleClientHttpRequestFactory();
        factory.setReadTimeout(45_000);//ms
        factory.setConnectTimeout(15_000);//ms
        restTemplate = new RestTemplate(factory);
        restTemplate.getMessageConverters().add(0,new StringHttpMessageConverter(StandardCharsets.UTF_8));
    }

    @Autowired
    private ControlNodeProxy appNode;

    @Override
    public ClientNodeRegisterResponse heartbeat(ClientNodeRegisterRequest clientNodeRegisterRequest) {
        return rpc(clientNodeRegisterRequest, "/jobClient/heartbeat",ClientNodeRegisterResponse.class);
    }

    private <T> T rpc(Object request, String path,Class<T> clazz) {
        String url = "http://"+appNode.ip() + ":" + appNode.port()+"/iohub-control" ;
        url+=path;
        HttpHeaders headers = new HttpHeaders();
        headers.add("Content-Type","application/json");
        HttpEntity<String> formEntity = new HttpEntity<String>(JSONAccessor.impl().format(request), headers);
        try {
            ResponseEntity<String> responseEntity = restTemplate.postForEntity(url, formEntity, String.class);
            int statusCodeValue = responseEntity.getStatusCodeValue();
            if (statusCodeValue==200) {
                return JSONAccessor.impl().read(responseEntity.getBody(), clazz);
            }
            return null;
        } catch (Exception e) {
            if (verbose) {
                log.error(e.getMessage());
            }
            return null;
        }
    }

    private <T> T restWithFile(Map<String,Object> params, String file,  String path, Class<T> clazz){
        String url = "http://"+appNode.ip() + ":" + appNode.port()+"/iohub-control" ;
        url+=path;
        HttpHeaders headers = new HttpHeaders();
        headers.add("Content-Type","multipart/form-data");
        MultiValueMap<String, Object> multiValueMap = new LinkedMultiValueMap<>();
        for (Map.Entry<String, Object> entry : params.entrySet()) {
            multiValueMap.add(entry.getKey(),entry.getValue());
        }
        multiValueMap.add("file",new FileSystemResource(file));

        HttpEntity<MultiValueMap<String, Object>> formEntity = new HttpEntity<>(multiValueMap, headers);
        try {
            ResponseEntity<String> responseEntity = restTemplate.postForEntity(url, formEntity, String.class);
            int statusCodeValue = responseEntity.getStatusCodeValue();
            if (statusCodeValue==200) {
                return JSONAccessor.impl().read(responseEntity.getBody(), clazz);
            }
            return null;
        } catch (Exception e) {
            log.error(e.getMessage());
            return null;
        }

    }

    @Override
    public TaskLockResponse lockClient(TaskLockRequest taskLockRequest) {
        return rpc(taskLockRequest, "/jobClient/lockClient",TaskLockResponse.class);
    }

    @Override
    public TaskLogResponse log(TaskLogRequest taskLogRequest) {
        return rpc(taskLogRequest, "/jobClient/log",TaskLogResponse.class);
    }

    @Override
    public PreFlowErrorResponse preFlowError(PreFlowErrorRequest preFlowErrorRequest) {
        return rpc(preFlowErrorRequest, "/jobClient/preFlowError", PreFlowErrorResponse.class);
    }
}

==> iohub-sdk-client-1.0-20250506.010408-81-sources.jar: com/ovopark/iohub/sdk/client/Client2ControlRestClient.java <==
package com.ovopark.iohub.sdk.client;

import com.ovopark.iohub.sdk.model.*;
import com.ovopark.iohub.sdk.model.outstream.JobRenderStartRequest;
import com.ovopark.iohub.sdk.model.outstream.JobRenderStartResponse;
import com.ovopark.iohub.sdk.model.outstream.JobRenderAssignWorkRequest;
import com.ovopark.iohub.sdk.model.outstream.JobRenderAssignWorkResponse;
import com.ovopark.kernel.shared.Config;
import com.ovopark.kernel.shared.JSONAccessor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.FileSystemResource;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.ResponseEntity;
import org.springframework.http.client.SimpleClientHttpRequestFactory;
import org.springframework.http.converter.StringHttpMessageConverter;
import org.springframework.stereotype.Component;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import java.nio.charset.StandardCharsets;
import java.util.Map;

@JobClientActive
@Slf4j
@Component
public class Client2ControlRestClient implements Client2ControlTransport {


    final boolean verbose= Config.ConfigPriority.option().getBoolean("iohub.client.io.verbose",true);

    private final RestTemplate restTemplate;

    public Client2ControlRestClient() {
        SimpleClientHttpRequestFactory factory = new SimpleClientHttpRequestFactory();
        factory.setReadTimeout(45_000);//ms
        factory.setConnectTimeout(15_000);//ms
        restTemplate = new RestTemplate(factory);
        restTemplate.getMessageConverters().add(0,new StringHttpMessageConverter(StandardCharsets.UTF_8));
    }

    @Autowired
    private ControlNodeProxy appNode;

    @Override
    public ClientNodeRegisterResponse heartbeat(ClientNodeRegisterRequest clientNodeRegisterRequest) {
        return rpc(clientNodeRegisterRequest, "/jobClient/heartbeat",ClientNodeRegisterResponse.class);
    }

    private <T> T rpc(Object request, String path,Class<T> clazz) {
        String url = "http://"+appNode.ip() + ":" + appNode.port()+"/iohub-control" ;
        url+=path;
        HttpHeaders headers = new HttpHeaders();
        headers.add("Content-Type","application/json");
        HttpEntity<String> formEntity = new HttpEntity<String>(JSONAccessor.impl().format(request), headers);
        try {
            ResponseEntity<String> responseEntity = restTemplate.postForEntity(url, formEntity, String.class);
            int statusCodeValue = responseEntity.getStatusCodeValue();
            if (statusCodeValue==200) {
                return JSONAccessor.impl().read(responseEntity.getBody(), clazz);
            }
            return null;
        } catch (Exception e) {
            if (verbose) {
                log.error(e.getMessage());
            }
            return null;
        }
    }

    private <T> T restWithFile(Map<String,Object> params, String file,  String path, Class<T> clazz){
        String url = "http://"+appNode.ip() + ":" + appNode.port()+"/iohub-control" ;
        url+=path;
        HttpHeaders headers = new HttpHeaders();
        headers.add("Content-Type","multipart/form-data");
        MultiValueMap<String, Object> multiValueMap = new LinkedMultiValueMap<>();
        for (Map.Entry<String, Object> entry : params.entrySet()) {
            multiValueMap.add(entry.getKey(),entry.getValue());
        }
        multiValueMap.add("file",new FileSystemResource(file));

        HttpEntity<MultiValueMap<String, Object>> formEntity = new HttpEntity<>(multiValueMap, headers);
        try {
            ResponseEntity<String> responseEntity = restTemplate.postForEntity(url, formEntity, String.class);
            int statusCodeValue = responseEntity.getStatusCodeValue();
            if (statusCodeValue==200) {
                return JSONAccessor.impl().read(responseEntity.getBody(), clazz);
            }
            return null;
        } catch (Exception e) {
            log.error(e.getMessage());
            return null;
        }

    }

    @Override
    public TaskLockResponse lockClient(TaskLockRequest taskLockRequest) {
        return rpc(taskLockRequest, "/jobClient/lockClient",TaskLockResponse.class);
    }

    @Override
    public TaskLogResponse log(TaskLogRequest taskLogRequest) {
        return rpc(taskLogRequest, "/jobClient/log",TaskLogResponse.class);
    }

    @Override
    public PreFlowErrorResponse preFlowError(PreFlowErrorRequest preFlowErrorRequest) {
        return rpc(preFlowErrorRequest, "/jobClient/preFlowError", PreFlowErrorResponse.class);
    }

    @Override
    public JobRenderStartResponse startJobRender(JobRenderStartRequest jobRenderStartRequest) {
        return rpc(jobRenderStartRequest, "/jobClient/jobRender/start", JobRenderStartResponse.class);
    }


    @Override
    public JobRenderAssignWorkResponse assignWorkJobRender(JobRenderAssignWorkRequest jobRenderAssignWorkRequest) {
        return rpc(jobRenderAssignWorkRequest, "/jobClient/jobRender/assignWork", JobRenderAssignWorkResponse.class);
    }
}
